==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-taskbar/translations/taskbar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="648"/>
        <source>Activate task %1</source>
        <translation>Activer la tâche %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="513"/>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="547"/>
        <source>To &amp;Desktop</source>
        <translation>Vers &amp;le bureau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="549"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tous les bureaux</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="557"/>
        <source>Desktop &amp;%1</source>
        <translation>Bureau &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="564"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Vers le bureau courant</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="572"/>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="575"/>
        <source>Resi&amp;ze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="582"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximiser</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="589"/>
        <source>Maximize vertically</source>
        <translation>Maximiser verticalement</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="594"/>
        <source>Maximize horizontally</source>
        <translation>Maximiser horizontalement</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="600"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="604"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimiser</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>Roll down</source>
        <translation>Enrouler vers le bas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="616"/>
        <source>Roll up</source>
        <translation>Enrouler vers le haut</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Layer</source>
        <translation>&amp;Disposition</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="626"/>
        <source>Always on &amp;top</source>
        <translation>Toujours au &amp;dessus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="632"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Always on &amp;bottom</source>
        <translation>Toujours en &amp;bas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="646"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Fermer le groupe</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Paramétrage du gestionnaire de tâches</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Afficher uniquement les fenêtres du bureau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Afficher uniquement les fenêtres de l&apos;écran du &amp;panneau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Afficher uniquement les fenêtres minimisées</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Relever les fenêtres  réduites du bureau actuel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Cycle de fenêtres sur le défilement de la roulette</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Groupement de fenêtres</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Largeur maximale des boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Hauteur maximale des boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Utilisez les icônes par WindowClass, si disponible</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>&amp;Rotation automatique des boutons lorsque le tableau est vertical</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Afficher une bulle au survol de la souris</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Style de boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Fermer d&apos;un clic du milieu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Icône et texte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Icône seule</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Texte seul</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Current</source>
        <translation>Courant</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-taskbar/translations/taskbar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="648"/>
        <source>Activate task %1</source>
        <translation>Activer la tâche %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="513"/>
        <source>Application</source>
        <translation>Application(s)</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="547"/>
        <source>To &amp;Desktop</source>
        <translation>Vers &amp;le bureau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="549"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Tous les bureaux</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="557"/>
        <source>Desktop &amp;%1</source>
        <translation>Bureau &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="564"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Vers le bureau courant</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="572"/>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="575"/>
        <source>Resi&amp;ze</source>
        <translation>Re&amp;dimensionner</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="582"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximiser</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="589"/>
        <source>Maximize vertically</source>
        <translation>Maximiser verticalement</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="594"/>
        <source>Maximize horizontally</source>
        <translation>Maximiser horizontalement</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="600"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="604"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimiser</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>Roll down</source>
        <translation>Dérouler vers le bas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="616"/>
        <source>Roll up</source>
        <translation>Dérouler vers le haut</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Layer</source>
        <translation>&amp;Disposition</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="626"/>
        <source>Always on &amp;top</source>
        <translation>Toujours au-&amp;dessus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="632"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Always on &amp;bottom</source>
        <translation>Toujours en &amp;bas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="646"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Fermer le groupe</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Paramétrages du gestionnaire de tâches</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Afficher uniquement les fenêtres du bureau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Afficher uniquement les fenêtres de l&apos;écran du &amp;panneau</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Afficher uniquement les fenêtres minimisées</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Faire apparaître les fenêtres réduites du bureau actuel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Faire défiler les fenêtres en utilisant la roulette</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Groupement de fenêtres</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Largeur maximale des boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Hauteur maximale des boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Utilisez les icônes par classe de fenêtre, si disponible</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>&amp;Rotation automatique des boutons lorsque la barre de tâche est verticale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Afficher une bulle au survol de la souris</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Style de boutons</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Fermer d&apos;un clic du milieu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Icône et texte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Icône seule</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Texte seul</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Current</source>
        <translation>Courant</translation>
    </message>
</context>
</TS>
